@@ -2,10 +2,10 @@
 
 use strict;
 use warnings;
-use String::Util qw(trim);
 use File::Basename;
 use File::Compare;
 use PostgresNode;
+use String::Util qw(trim);
 use Test::More;
 
 # Expected folder where expected output will be present
@@ -53,6 +53,16 @@ my $node = PostgresNode->get_new_node('test');
 my $pgdata = $node->data_dir;
 $node->dump_info;
 $node->init;
+                                                                                
+# PG's major server version                                                     
+open my $FH_PG_VERSION, '<', "${pgdata}/PG_VERSION";                            
+my $major_version = trim(<$FH_PG_VERSION>);                                     
+close $FH_PG_VERSION;                                                           
+                                                                                
+if ($major_version <= 12)                                                       
+{                                                                               
+    plan skip_all => "pg_stat_statements test cases for versions 12 and below.";
+}                                                                               
 
 # Update postgresql.conf to include/load pg_stat_monitor library   
 $node->append_conf('postgresql.conf', "shared_preload_libraries = 'pg_stat_statements,pg_stat_monitor'");
@@ -61,6 +71,7 @@ $node->append_conf('postgresql.conf', "pg_stat_statements.track_utility = off");
 $node->append_conf('postgresql.conf', "pg_stat_monitor.pgsm_bucket_time = 1800");
 $node->append_conf('postgresql.conf', "track_io_timing = on");
 $node->append_conf('postgresql.conf', "pg_stat_monitor.pgsm_track_utility = no");
+$node->append_conf('postgresql.conf', "pg_stat_monitor.pgsm_normalized_query = yes");
 
 # Start server
 my $rt_value = $node->start;
